<?php
/**
 * @file
 * Functions for coders to use to make Drupal life easier with codit module.
 */

/**
 * Loads current node entity or term entity and returns the Entity object.
 *
 * @return object
 *   The entity object that was loaded.
 */
function codit_load_the_entity() {
  // Attempt to load the node.
  $o_entity = menu_get_object();
  // Try loading the term  if term is not available.
  $o_entity = (!empty($o_entity)) ? $o_entity : menu_get_object('taxonomy_term', 2);
  return $o_entity;
}


/**
 * Get the bundle of current page by node type, vocabulary machine name or NULL.
 *
 * @param object $o_entity
 *   The fully loaded entity.
 *
 * @return string
 *   The node bundle(type), the vocabulary machine name or NULL if neither.
 */
function codit_get_entity_bundle($o_entity) {
  // Check to see if it is a node or a term.
  if (!empty($o_entity->vocabulary_machine_name)) {
    // Means this is a vocabulary term page.
    $s_bundle = $o_entity->vocabulary_machine_name;
  }
  elseif (!empty($o_entity->type)) {
    // Means this is a node.
    $s_bundle = $o_entity->type;
  }
  else {
    $s_bundle = NULL;
  }

  return $s_bundle;
}


/**
 * Outputs a template tracer opening comment if user has permission to see it.
 *
 * @param string $s_file
 *   The file ' __FILE__' that is calling the tracer.
 * @param mixed $optional_message
 *   Anything you want included in the template tracer output.
 */
function codit_tto($s_file = 'codit_tto() called incorrectly.  Must be codit_tto(__FILE__)', $optional_message = '') {
  print _codit_tt($s_file, $optional_message, TRUE);
}


/**
 * Outputs a template tracer closing comment if user has permission to see it.
 *
 * @param string $s_file
 *   The file '__FILE__' that is calling the tracer.
 * @param mixed $optional_message
 *   Anything you want included in the template tracer output.
 */
function codit_ttc($s_file = 'codit_ttc() called incorrectly.  Must be codit_ttc(__FILE__)', $optional_message = '') {
  print _codit_tt($s_file, $optional_message, FALSE);
}


/**
 * The base function for Template Tracers. Should not be called directly.
 *
 * @param string $s_file
 *   The file '__FILE__' that is calling the tracer.
 * @param mixed $optional_message
 *   Anything to include in the template tracer output.
 * @param bool $b_open
 *   TRUE if the it is an opening tracer, FALSE if is is closing tracer.
 *
 * @return string
 *   HTML comments to output.
 */
function _codit_tt($s_file = '_codit_tt() called incorrectly.  Must call codit_tto(__FILE__) or codit_ttc(__FILE__)', $optional_message = '', $b_open = TRUE) {
  $s_tag = ($b_open) ? '<TEMPLATE>' : '</TEMPLATE>';
  if (user_access('view codit template tracers')) {
    if ((is_array($optional_message)) || (is_object($optional_message))) {
      // Means it is a array or opject, so convert it to a pretty string.
      $optional_message = print_r($optional_message, TRUE);
    }
    $optional_message = (!empty($optional_message)) ? "<!-- Message: $optional_message -->\n" : '';
    return ("<!-- $s_tag $s_file -->\n $optional_message");
  }
  return '';
}


/**
 * Checks permissions and presence of $_GET debug to output debug information.
 *
 * @param mixed $thing_to_output
 *   The array, object, number or string to output.
 * @param string $s_trigger
 *   The value in the $_GET to look for to output debug  ?debugslug=[s_trigger].
 * @param string $s_message
 *   An optional message that can accompany the output.
 *
 * @return bool
 *   Representing whether the user permission AND the trigger value
 *   was present in the GET
 */
function codit_debug($thing_to_output = array(), $s_trigger = '', $s_message = '') {
  // Check permissions to see if user is allowed to see debug.
  if (user_access('view codit debug output')) {
    // Check to see if kpr is available for nice ouput of arrays or objects.
    $f_output_it = (function_exists('kpr')) ? 'kpr' : 'print_r';
    // Get the site's debug slug.
    $s_debug_slug = variable_get('codit_debug_request_slug', 'debug');
    // Check the $_GET.
    if (!empty($_GET) && !empty($_GET[$s_debug_slug]) && (!empty($s_trigger)) && ($_GET[$s_debug_slug] == $s_trigger)) {
      if (!empty($s_message)) {
        $f_output_it("Message: $s_message");
      }
      if ($f_output_it === 'kpr') {
        $f_output_it('Debug Output: ');
        $f_output_it($thing_to_output);
      }
      else {
        print "<pre>\n";
        $f_output_it('Debug Output: ');
        $f_output_it($thing_to_output);
        print "</pre>\n";
      }
      return TRUE;
    }
  }
  return FALSE;
}
